@@ -18,6 +18,10 @@ class JsonChecker(Checker[str]):
     def check(self, text: T) -> Optional[str]:
         logger.trace(f"Trying json checker")
 
+        # https://github.com/Ciphey/Ciphey/issues/389
+        if text.isdigit():
+            return None
+
         try:
             json.loads(text)
             return ""
@@ -34,5 +38,3 @@ class JsonChecker(Checker[str]):
     @staticmethod
     def getParams() -> Optional[Dict[str, ParamSpec]]:
         pass
-
-
