@@ -15,4 +15,10 @@ from . import (
     leet,
     decimal,
     base69,
+    baudot,
+    multi_tap,
+    url,
+    tap_code,
+    brainfuck,
+    uuencode,
 )
