@@ -1,26 +1,16 @@
 from typing import Optional, Dict, Any
 
-from loguru import logger
-
 import ciphey
 from ciphey.iface import registry, Translation, ParamSpec
 
 
 @registry.register
 class Leet(ciphey.iface.Decoder[str, str]):
-    @staticmethod
-    def getTarget() -> str:
-        return "leet"
-
     def decode(self, text: str) -> Optional[str]:
         for src, dst in self.translate.items():
             text = text.replace(src, dst)
         return text
 
-    @staticmethod
-    def getParams() -> Optional[Dict[str, Dict[str, Any]]]:
-        pass
-
     @staticmethod
     def priority() -> float:
         return 0.05
@@ -37,4 +27,8 @@ class Leet(ciphey.iface.Decoder[str, str]):
                 req=False,
                 default="cipheydists::translate::leet",
             )
-        }
\ No newline at end of file
+        }
+
+    @staticmethod
+    def getTarget() -> str:
+        return "leet"
