@@ -1,5 +1,4 @@
 from typing import Optional, Dict, Any, List
-import re
 from loguru import logger
 import ciphey
 from ciphey.iface import registry
@@ -8,21 +7,14 @@ from ciphey.iface import registry
 @registry.register
 class MorseCode(ciphey.iface.Decoder[str, str]):
     # A priority list for char/word boundaries
-    BOUNDARIES = {" ": 1, "/": 2, "\n": 3, ".": -1, "-": -1}
+    BOUNDARIES = {" ": 1, "/": 2, "\n": 3}
+    PURGE = {ord(c): None for c in BOUNDARIES.keys()}
     MAX_PRIORITY = 3
     ALLOWED = {".", "-", " ", "/", "\n"}
     MORSE_CODE_DICT: Dict[str, str]
     MORSE_CODE_DICT_INV: Dict[str, str]
 
-    @staticmethod
-    def getTarget() -> str:
-        return "morse"
-
     def decode(self, text: str) -> Optional[str]:
-        # Trim end
-        while text[-1] in self.BOUNDARIES:
-            text = text[:-1]
-
         logger.trace("Attempting morse code")
 
         char_boundary = word_boundary = None
@@ -33,6 +25,8 @@ class MorseCode(ciphey.iface.Decoder[str, str]):
         for i in text:
             i_priority = self.BOUNDARIES.get(i)
             if i_priority is None:
+                if i in self.ALLOWED:
+                  continue
                 logger.trace(f"Non-morse char '{i}' found")
                 return None
 
@@ -51,7 +45,7 @@ class MorseCode(ciphey.iface.Decoder[str, str]):
             char_boundary = i
 
         logger.trace(
-            f"'Char boundary is '{char_boundary}', and word boundary is '{word_boundary}'"
+            f"Char boundary is unicode {ord(char_boundary)}, and word boundary is unicode {ord(word_boundary) if word_boundary is not None else None}"
         )
 
         result = ""
@@ -59,10 +53,13 @@ class MorseCode(ciphey.iface.Decoder[str, str]):
         for word in text.split(word_boundary) if word_boundary else [text]:
             logger.trace(f"Attempting to decode word {word}")
             for char in word.split(char_boundary):
+                char = char.translate(self.PURGE)
+                if len(char) == 0:
+                  continue
                 try:
                     m = self.MORSE_CODE_DICT_INV[char]
                 except KeyError:
-                    logger.trace(f"Invalid codeword '{word}' found")
+                    logger.trace(f"Invalid codeword '{char}' found")
                     return None
                 result = result + m
             # after every word add a space
@@ -75,6 +72,17 @@ class MorseCode(ciphey.iface.Decoder[str, str]):
         logger.debug(f"Morse code successful, returning {result}")
         return result.strip().upper()
 
+    @staticmethod
+    def priority() -> float:
+        return 0.05
+
+    def __init__(self, config: ciphey.iface.Config):
+        super().__init__(config)
+        self.MORSE_CODE_DICT = config.get_resource(
+            self._params()["dict"], ciphey.iface.Translation
+        )
+        self.MORSE_CODE_DICT_INV = {v: k for k, v in self.MORSE_CODE_DICT.items()}
+
     @staticmethod
     def getParams() -> Optional[Dict[str, ciphey.iface.ParamSpec]]:
         return {
@@ -86,16 +94,5 @@ class MorseCode(ciphey.iface.Decoder[str, str]):
         }
 
     @staticmethod
-    def getName() -> str:
+    def getTarget() -> str:
         return "morse"
-
-    @staticmethod
-    def priority() -> float:
-        return 0.05
-
-    def __init__(self, config: ciphey.iface.Config):
-        super().__init__(config)
-        self.MORSE_CODE_DICT = config.get_resource(
-            self._params()["dict"], ciphey.iface.Translation
-        )
-        self.MORSE_CODE_DICT_INV = {v: k for k, v in self.MORSE_CODE_DICT.items()}
