@@ -5,7 +5,7 @@
 ██║     ██║██╔═══╝ ██╔══██║██╔══╝    ╚██╔╝  
 ╚██████╗██║██║     ██║  ██║███████╗   ██║ 
 https://github.com/ciphey
-https://docs.ciphey.online
+https://github.com/Ciphey/Ciphey/wiki
 
 The cycle goes:
 main -> argparsing (if needed) -> call_encryption -> new Ciphey object -> decrypt() -> produceProbTable ->
@@ -131,7 +131,7 @@ def main(**kwargs):
     """Ciphey - Automated Decryption Tool
     
     Documentation: 
-    https://docs.ciphey.online\n
+    https://github.com/Ciphey/Ciphey/wiki\n
     Discord (support here, we're online most of the day):
     https://discord.ciphey.online/\n
     GitHub: 
@@ -239,15 +239,16 @@ def main(**kwargs):
 
             all_procedure()
 
-            # print("No inputs were given to Ciphey. For usage, run ciphey --help")
             return None
 
-    if config.objs["format"] == str and type(kwargs["text"]) is bytes:
+    if issubclass(config.objs["format"], type(kwargs["text"])):
+        pass
+    elif config.objs["format"] == str and type(kwargs["text"]) is bytes:
         kwargs["text"] = kwargs["text"].decode("utf-8")
     elif config.objs["format"] == bytes and type(kwargs["text"]) is str:
         kwargs["text"] = kwargs["text"].encode("utf-8")
     else:
-        raise TypeError(f"Cannot load type {config.format}")
+        raise TypeError(f"Cannot load type {config.format} from {type(kwargs['text'])}")
 
     result: Optional[str]
 
